"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true,
});
exports.default = void 0;
var _timers = require("timers");
const MAX_QUEUE_TIME_SPAN_MS = 3000;
class CDPMessagesQueueLogging {
  #messageQueueSize = 0;
  #maxMessageQueueSize = 0;
  #messagesMemoryUsage = 0;
  #maxMessageQueueCombinedStringSize = 0;
  #loggingTimeout = null;
  #debounceStartMs = 0;
  #onHighMessageQueueSize;
  constructor(onHighMessageQueueSize) {
    this.#onHighMessageQueueSize = onHighMessageQueueSize;
  }
  messageReceived(messageSize) {
    this.#messageQueueSize++;
    this.#messagesMemoryUsage += messageSize;
    if (this.#messageQueueSize > this.#maxMessageQueueSize) {
      this.#maxMessageQueueSize = this.#messageQueueSize;
      this.#maxMessageQueueCombinedStringSize = this.#messagesMemoryUsage;
      if (this.#loggingTimeout) {
        this.#loggingTimeout.refresh();
      } else {
        this.#debounceStartMs = new Date().getTime();
        this.#loggingTimeout = (0, _timers.setTimeout)(() => {
          this.#onHighMessageQueueSize(
            this.#maxMessageQueueSize,
            this.#maxMessageQueueCombinedStringSize * 2
          );
          this.#loggingTimeout = null;
          this.#maxMessageQueueSize = 0;
          this.#maxMessageQueueCombinedStringSize = 0;
        }, MAX_QUEUE_TIME_SPAN_MS).unref();
      }
    }
  }
  messageProcessed(messageSize) {
    this.#messageQueueSize--;
    this.#messagesMemoryUsage -= messageSize;
  }
}
exports.default = CDPMessagesQueueLogging;
